@@ -20,4 +20,4 @@ class Option():
 
 
 DEFAULT_CONFIG: Config = Config()
-DEFAULT_OPTION: Option = Option(level=3, is_exact=False, use_api=False)
+DEFAULT_OPTION: Option = Option(level=3, is_exact=True, use_api=False)
