@@ -1,13 +1,39 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from typing import Dict, List, Tuple
-
+import sys
+print(sys.path)
 from ..lib.const import ADDRESS, CITY, LEVEL, PREF, TOWN
 from ..lib.config import DEFAULT_OPTION
 from ..normalize import normalize
 
 
 TEST_PATTERNS: List[Tuple[str, Dict[str, str]]] = [
+
+        # 追加テスト 
+        ('埼玉県鶴ヶ島市新町3-5', {PREF: "埼玉県", CITY: "鶴ヶ島市", TOWN: "新町三丁目", ADDRESS: "5", LEVEL: 3}),
+        ('宮城県加美郡加美町原八幡浦32', {PREF: "宮城県", CITY: "加美郡加美町", TOWN: "原八幡浦", ADDRESS: "32", LEVEL: 3}),
+        ('宮城県塩竈市向ケ丘18－1', {PREF: "宮城県", CITY: "塩竈市", TOWN: "向ケ丘", ADDRESS: "18-1", LEVEL: 3}),
+        ('東京都府中市南町6-32', {PREF: "東京都", CITY: "府中市", TOWN: "南町", ADDRESS: "6", LEVEL: 3}),
+        # 市制施行
+        ('福岡県筑紫郡那珂川町大字松木6-2', {PREF: "福岡県", CITY: "那珂川市", TOWN: "松木六丁目", ADDRESS: "2", LEVEL: 3}),
+        # 合併
+        ('下都賀郡岩舟町大字静5132番地2', {PREF: "栃木県", CITY: "栃木市", TOWN: "岩舟町静", ADDRESS: "5132-2", LEVEL: 3}),
+        # 該当データなし
+        ('名古屋市瑞穂区彌富町字月見ケ岡32', {PREF: "愛知県", CITY: "名古屋市瑞穂区", TOWN: "弥富町月見ケ岡", ADDRESS: "32", LEVEL: 3}),
+        ('愛知県名古屋市瑞穂区弥富町月見ケ岡32', {PREF: "愛知県", CITY: "名古屋市瑞穂区", TOWN: "弥富町月見ケ岡", ADDRESS: "32", LEVEL: 3}),
+        # そのほか
+        ('龍ケ崎市藤ケ丘六丁目32', {PREF: "茨城県", CITY: "龍ヶ崎市", TOWN: "藤ケ丘六丁目", ADDRESS: "32", LEVEL: 3}),
+        ('新潟県北蒲原郡聖籠町大字三賀28', {PREF: "新潟県", CITY: "北蒲原郡聖籠町", TOWN: "大字三賀", ADDRESS: "28", LEVEL: 3}),
+        ('宮崎県都城市北原町24', {PREF: "宮崎県", CITY: "都城市", TOWN: "北原町", ADDRESS: "24", LEVEL: 3}),
+        ('都城市北原町24', {PREF: "宮崎県", CITY: "都城市", TOWN: "北原町", ADDRESS: "24", LEVEL: 3}),
+        ('山梨県都留市上谷一丁目1番1号', {PREF: "山梨県", CITY: "都留市", TOWN: "上谷一丁目", ADDRESS: "1-1", LEVEL: 3}),
+        ('広島県安芸郡府中町大通三丁目5番1号', {PREF: "広島県", CITY: "安芸郡府中町", TOWN: "大通三丁目", ADDRESS: "5-1", LEVEL: 3}),
+        ('広島県府中市行縢町38', {PREF: "広島県", CITY: "府中市", TOWN: "行縢町", ADDRESS: "38", LEVEL: 3}),
+        ('長崎県諫早市東小路町7ｰ1', {PREF: "長崎県", CITY: "諫早市", TOWN: "東小路町", ADDRESS: "7-1", LEVEL: 3}),          
+        ('長崎県諌早市東小路町7ｰ1', {PREF: "長崎県", CITY: "諫早市", TOWN: "東小路町", ADDRESS: "7-1", LEVEL: 3}),
+        
+        ### TrueScript版のテスト
         ('大阪府堺市北区新金岡町4丁1−8', {PREF: "大阪府", CITY: "堺市北区", TOWN: "新金岡町四丁", ADDRESS: "1-8", LEVEL: 3}),
         ('大阪府堺市北区新金岡町４丁１ー８', {PREF: "大阪府", CITY: "堺市北区", TOWN: "新金岡町四丁", ADDRESS: "1-8", LEVEL: 3}),
         ('和歌山県串本町串本1234', {PREF: "和歌山県", CITY: "東牟婁郡串本町", TOWN: "串本", ADDRESS: "1234", LEVEL: 3}),
@@ -151,7 +177,7 @@ TEST_PATTERNS: List[Tuple[str, Dict[str, str]]] = [
         ('串本町串本1234', {PREF: "和歌山県", CITY: "東牟婁郡串本町", TOWN: "串本", ADDRESS: "1234", LEVEL: 3}),
         ('広島県府中市府川町315', {PREF: "広島県", CITY: "府中市", TOWN: "府川町", ADDRESS: "315", LEVEL: 3}),
         ('府中市府川町315', {PREF: "広島県", CITY: "府中市", TOWN: "府川町", ADDRESS: "315", LEVEL: 3}),
-        ('府中市宮西町2丁目24番地', {PREF: "東京都", CITY: "府中市", TOWN: "宮西町二丁目", ADDRESS: "24", LEVEL: 3}),
+        ('東京都府中市宮西町2丁目24番地', {PREF: "東京都", CITY: "府中市", TOWN: "宮西町二丁目", ADDRESS: "24", LEVEL: 3}),
         ('三重県三重郡菰野町大字大強原2796', {PREF: "三重県", CITY: "三重郡菰野町", TOWN: "大字大強原", ADDRESS: "2796", LEVEL: 3}),
         ('三重県三重郡菰野町大強原2796', {PREF: "三重県", CITY: "三重郡菰野町", TOWN: "大字大強原", ADDRESS: "2796", LEVEL: 3}),
         ('福岡県北九州市小倉南区大字井手浦874', {PREF: "福岡県", CITY: "北九州市小倉南区", TOWN: "大字井手浦", ADDRESS: "874", LEVEL: 3}),
